

set -ex



test -f $PREFIX/cuda-compat/libcuda.so.550.54.15
test -L $PREFIX/cuda-compat/libcuda.so.1
test -L $PREFIX/cuda-compat/libcuda.so
test -f $PREFIX/cuda-compat/libnvidia-nvvm.so.550.54.15
test -L $PREFIX/cuda-compat/libnvidia-nvvm.so.4
test -L $PREFIX/cuda-compat/libnvidia-nvvm.so
test -f $PREFIX/cuda-compat/libnvidia-ptxjitcompiler.so.550.54.15
test -L $PREFIX/cuda-compat/libnvidia-ptxjitcompiler.so.1
test -f $PREFIX/cuda-compat/libcudadebugger.so.550.54.15
test -L $PREFIX/cuda-compat/libcudadebugger.so.1
exit 0
